# cmip6_aws


[![image](https://img.shields.io/pypi/v/cmip6_aws.svg)](https://pypi.python.org/pypi/cmip6_aws)
[![image](https://img.shields.io/conda/vn/conda-forge/cmip6_aws.svg)](https://anaconda.org/conda-forge/cmip6_aws)


**download data from NASA Earth Exchange Global Daily Downscaled Projections (NEX-GDDP-CMIP6)**


-   Free software: MIT license
-   Documentation: https://advancehs.github.io/cmip6_aws
    

## install 

```
pip install cmip6-aws

```
## Compile to exe

- choose file - open in terminal

```

pyinstaller -F -w main.py

```
![](https://advance-markdown.oss-cn-shenzhen.aliyuncs.com/img/20240805193559.png)